$VAR1 = {
         'en' => {
                  'insert'                   => 'Insert',
                  'openfile'                 => 'Explorer',
                  'files'                    => 'Explorer',
                  'editmysqluserrights'      => 'Database',
                  'save'                     => 'Save',
                  'rename'                   => 'Rename',
                  'email'                    => 'Email Adress',
                  'boxen'                    => 'boxen',
                  'wrongusername'            => 'Wrong Username',
                  'password'                 => 'Password',
                  'edittable'                => 'Database',
                  'admincenter'              => 'Admin',
                  'logout'                   => 'Logout',
                  'endtable'                 => 'at end',
                  'category'                 => 'Category',
                  'newmenu'                  => 'Create new Menu',
                  'showaddtranslation'       => 'Translation',
                  'multipleaction'           => 'Database',
                  'name'                     => 'Name',
                  'movetreeviewentry'        => 'TreeView',
                  'details'                  => 'Details',
                  'properties'               => 'Properties',
                  'importfirefox'            => 'Import FireFox Bookmarks',
                  'dumpdatabase'             => 'Database',
                  'trash'                    => 'Trash',
                  'unselect_all'             => 'Select none',
                  'translate'                => 'Translate',
                  'showrights'               => 'Show rights',
                  'editvmenu'                => 'Edit V-Menu',
                  'delete'                   => 'Delete',
                  'chars'                    => 'Chars left:',
                  'links_pro_page'           => 'links/page',
                  'non_unique'               => 'Non_unique',
                  'saveedittable'            => 'Database',
                  'mailsendet'               => '<div align="center">You will receive a mail with your Password<br/></div>',
                  'showfiles'                => 'Explorer',
                  'deletefile'               => 'Explorer',
                  'insertafter'              => 'After',
                  'changecurrentdb'          => 'Change Database User',
                  'cardinality'              => 'Cardinality',
                  'createnewtable'           => 'Database',
                  'speichern'                => 'Speichern',
                  'showdatabases'            => 'Databases',
                  'pass'                     => 'Password',
                  'truncate'                 => 'Truncate',
                  'showeditindex'            => 'Database',
                  'edithmenu'                => 'Edit H-Menu',
                  'editnavi'                 => 'Edit Navigation',
                  'sort'                     => 'Sort',
                  'edittableprops'           => 'Database',
                  'fields'                   => 'Fields',
                  'select_all'               => 'Select All',
                  'index_type'               => 'Index_type',
                  'profile'                  => 'Profile',
                  'next'                     => 'Next',
                  'importoperabookmarks'     => 'Bookmarks',
                  'feeds'                    => 'Rss',
                  'upentry'                  => 'Sort',
                  'exportdatabase'           => 'Database',
                  'comments'                 => 'Comments',
                  'newentry'                 => 'New Entry',
                  'deletetreeviewentrys'     => 'Delete',
                  'editaction'               => 'Edit Action',
                  'createdatabase'           => 'New Database',
                  'nachricht'                => 'Message',
                  'chmodfile'                => 'Explorer',
                  'makedir'                  => 'Explorer',
                  'user'                     => 'user',
                  'lostpass'                 => 'Lost Password',
                  'savefile'                 => 'Explorer',
                  'newfolder'                => 'Append',
                  'export'                   => 'Export',
                  'showprocesslist'          => 'Processlist',
                  'haveacount'               => 'You already have an Acount',
                  'savetreeviewentry'        => 'TreeView',
                  'links'                    => 'Bookmarks',
                  'newindex'                 => 'New Index',
                  'failed: invalid code'     => 'failed: invalid code',
                  'admin'                    => 'Admin',
                  'addtreeviewentry'         => 'Add new entry',
                  'newdir'                   => 'Explorer',
                  'createuser'               => 'Create User',
                  'saverights'               => 'Database',
                  'editentry'                => 'Edit Entry',
                  'getpass'                  => 'Lost Password',
                  'null'                     => 'Null',
                  'retry'                    => 'retry',
                  'exportoperabookmarks'     => 'Bookmarks',
                  'multipledbaction'         => 'Database',
                  'preview'                  => 'Preview',
                  'bookmarks'                => 'Bookmarks',
                  'type'                     => 'type',
                  'repairtable'              => 'Database',
                  'fileopen'                 => 'fileopen',
                  'newpass'                  => 'New Password',
                  'rows in effect'           => 'rows in effect',
                  'dropdatabase'             => 'Drop Database',
                  'after'                    => 'after',
                  'city'                     => 'City',
                  'column_name'              => 'Column_name',
                  'showtables'               => 'Show Tables',
                  'analyzetable'             => 'Analyze Table',
                  'limit'                    => 'Limit',
                  'newmessagereleased'       => 'New Message saved',
                  'familyname'               => 'Family Name',
                  'auswahl aufheben'         => 'Auswahl aufheben',
                  't_regtext'                => 'Register',
                  'datenbank'                => 'datenbank',
                  'back'                     => 'Back',
                  'readmore'                 => 'Read More',
                  'phone'                    => 'Phone Number',
                  'showtabledetails'         => 'Show Table Details',
                  'host'                     => 'Host',
                  'createindex'              => 'Database',
                  'register'                 => 'Register',
                  'navigation'               => 'Navigation',
                  'edittranslation'          => 'Translation',
                  'mailsubject'              => 'Register',
                  'permissiondenied'         => 'permission denied',
                  'indexover'                => 'Indexover',
                  'optimize'                 => 'Optimize',
                  'news'                     => 'Logbook',
                  'execsql'                  => 'Exec Sql',
                  'importfirefoxbookmarks'   => 'importfirefoxbookmarks',
                  'headline'                 => 'Headline',
                  'rights'                   => 'Rights',
                  'edit entry'               => 'Edit Entry',
                  'table'                    => 'Table',
                  'renamefile'               => 'Rename',
                  'searchdatabase'           => 'Database',
                  'drop_database'            => 'drop_database',
                  'caption'                  => 'Caption',
                  'regmessage'               => 'You receive this email from Lindnerei.de',
                  'dragsharelink'            => 'Drag link to your Bookmarks',
                  'processlist'              => 'Processlist',
                  'lang'                     => 'en',
                  'sql'                      => 'SQL',
                  'newfile'                  => 'Explorer',
                  'folderfirst'              => 'Folder first',
                  'createtable'              => 'Create Table',
                  'saveentry'                => 'Save Entry',
                  'edittree'                 => 'Edit',
                  'username'                 => 'User',
                  'catslist'                 => 'catslist',
                  'showvariables'            => 'Variables',
                  'showusers'                => 'Show Users',
                  'deletetreeviewentry'      => 'Delete',
                  'showtable'                => 'Show Table',
                  'explorer'                 => 'Explorer',
                  'changeautoincrementvalue' => 'Database',
                  'news_pro_page'            => 'Messages/Page',
                  'optimizetable'            => 'Optimize Table',
                  'welcome'                  => 'Welcome',
                  'packed'                   => 'Packed',
                  'newpost'                  => 'New Message',
                  'edit'                     => 'Edit',
                  'size'                     => 'Size',
                  'permalink'                => 'permalink',
                  'body'                     => 'Body',
                  'summary'                  => 'Summary',
                  'checkformsddfsds'         => 'true',
                  'edittreeviewentry'        => 'Editor',
                  'editfile'                 => 'Editor',
                  'newfileadded'             => 'New File created',
                  'referer'                  => 'Referer',
                  'editlinks'                => 'editlinks',
                  'create'                   => 'Create',
                  'choosefile'               => 'Choose Attachment',
                  'shownewentry'             => 'New Entry',
                  'deleteentry'              => 'Delete Entry',
                  'env'                      => 'Env',
                  'repair'                   => 'Repair',
                  'key_name'                 => 'Key_name',
                  'database'                 => 'Database',
                  'reg'                      => 'Register',
                  'regexp'                   => 'Regular Expression',
                  'inserttext'               => 'Insert Text',
                  'firstname'                => 'Firstname',
                  'search'                   => 'Search',
                  'done'                     => 'Done',
                  'street'                   => 'Street',
                  'insertpass'               => 'Insert Password',
                  'edit table'               => 'Edit Table',
                  'about'                    => 'About',
                  'floodtext'                => 'To many Posts',
                  'field'                    => 'field',
                  'answers'                  => 'Answers',
                  'sites'                    => 'Sites',
                  'show'                     => 'Show',
                  'truncatetable'            => 'Truncate',
                  'rebuild'                  => 'Rebuild',
                  'nomail'                   => 'No Email Adress given.',
                  'newcol'                   => 'New Column',
                  'insertname'               => 'Insert Your Name',
                  'editconfiguration'        => 'Configuration',
                  'fileexists'               => 'File already Exists',
                  'newtreeviewentry'         => 'New Entry',
                  'pocesslist'               => 'pocesslist',
                  'downentry'                => 'Sort',
                  'buildfeeds'               => 'Rss',
                  'userexits'                => 'This name is already in use.<br/>',
                  'newtable'                 => 'New Table',
                  'edittreeview'             => 'Edit',
                  'wrongpass'                => 'Wrong Password',
                  'starttable'               => 'at start',
                  'sub_part'                 => 'sub_part',
                  'sharelink'                => 'Share',
                  'impressum'                => 'Impressum',
                  'gbook_body'               => 'Write your entry',
                  'mysqldump'                => 'Mysql dump',
                  'realy'                    => 'Realy',
                  'help'                     => 'Help',
                  'postcode'                 => 'Postcode',
                  'editmessage'              => 'Edit',
                  'gbook'                    => 'Gbook',
                  'connect'                  => 'Connect',
                  'dumptable'                => 'Databases',
                  'databases'                => 'Databases',
                  'blog'                     => 'Logbook',
                  'settings'                 => 'Settings',
                  'seq_in_index'             => 'Seq_in_index',
                  'reply'                    => 'Reply',
                  'comment'                  => 'Comment',
                  'savetranslate'            => 'savetranslate',
                  'selected'                 => 'Select all',
                  'showwindow'               => 'Show Windows',
                  'newmessage'               => 'New Topic',
                  'changeengine'             => 'Change Engine'
         },
         'de' => {
                  'insert'                   => 'Einf&#252;gen',
                  'editmysqluserrights'      => 'Datenbank',
                  'files'                    => 'Explorer',
                  'openfile'                 => 'Explorer',
                  'save'                     => 'Speichern',
                  'rename'                   => 'Umbenennen',
                  'email'                    => 'Email Adresse',
                  'boxen'                    => 'boxen',
                  'password'                 => 'Passwort',
                  'wrongusername'            => 'Du hast keinen oder einen ung&#252;ltigen usernamen eingegeben, bitte eingabe wiederhohlen.<br/>',
                  'admincenter'              => 'Admin',
                  'edittable'                => 'Database',
                  'logout'                   => 'Abmelden',
                  'category'                 => 'Kategorie',
                  'endtable'                 => 'am ende',
                  'dein name'                => 'Dein name',
                  'newmenu'                  => 'Neues Menu erstellen',
                  'showaddtranslation'       => 'showaddtranslation',
                  'multipleaction'           => 'Datenbank',
                  'name'                     => 'Name',
                  'details'                  => 'Details',
                  'movetreeviewentry'        => 'Bearbeiten',
                  'dumpdatabase'             => 'Datenbank',
                  'importfirefox'            => 'Firefox Lesezeichen importieren',
                  'properties'               => 'Einstellungen',
                  'nachricht senden'         => 'Nachricht senden',
                  'trash'                    => 'M&#252;lleimer',
                  'unselect_all'             => 'Auswahl aufheben',
                  'translate'                => '&#220;bersetzen',
                  'chars'                    => 'Zeichen &#252;brig:',
                  'delete'                   => 'Löschen',
                  'editvmenu'                => 'Vertikales Menu',
                  'showrights'               => 'Datenbank',
                  'sitemap'                  => 'Lesezeichen',
                  'links_pro_page'           => 'Eintr&#228;ge/Seite',
                  'non_unique'               => 'Nicht Unique',
                  'saveedittable'            => 'Datenbank',
                  'mailsendet'               => '<div align="center">Du hast eine email mit Ihren Passwort zugesendet bekommen.<br/></div>',
                  'showfiles'                => 'Explorer',
                  'deletefile'               => 'Explorer',
                  'insertafter'              => 'Einf&#252;gen',
                  'cardinality'              => 'Kardinalit&#228;t',
                  'changecurrentdb'          => 'Benutzer wechseln',
                  'createnewtable'           => 'Neue Tabelle erstellen',
                  'pass'                     => 'Passwort',
                  'showdatabases'            => 'Datenbanken',
                  'speichern'                => 'Speichern',
                  'edithmenu'                => 'Horizontales Menu',
                  'showeditindex'            => 'Datenbank',
                  'truncate'                 => 'Leeren',
                  'editnavi'                 => 'Navigation',
                  'edittableprops'           => 'Bearbeiten',
                  'sort'                     => 'Sortieren',
                  'fields'                   => 'Spalten',
                  'select_all'               => 'Alle ausw&#228;hlen',
                  'index_type'               => 'Type',
                  'profile'                  => 'Einstellungen',
                  'next'                     => 'Weiter',
                  'importoperabookmarks'     => 'Opera Lezeichen importieren',
                  'feeds'                    => 'Rss',
                  'upentry'                  => 'Datenbank',
                  'exportdatabase'           => 'Datenbank',
                  'comments'                 => 'Kommentare',
                  'newentry'                 => 'Neuer Eintrag',
                  'deletetreeviewentrys'     => 'deletetreeviewentrys',
                  'createdatabase'           => 'Neue Datenbank',
                  'editaction'               => 'Aktion bearbeiten',
                  'chmodfile'                => 'Explorer',
                  'nachricht'                => 'nachricht',
                  'makedir'                  => 'Explorer',
                  'lostpass'                 => 'Passwort vergessen',
                  'user'                     => 'user',
                  'export'                   => 'Exportieren',
                  'newfolder'                => 'Anh&#228;ngen',
                  'savefile'                 => 'Speichern',
                  'haveacount'               => 'Du hast bereits einen Acount',
                  'showprocesslist'          => 'Processlist',
                  'links'                    => 'Lesezeichen',
                  'savetreeviewentry'        => 'TreeView',
                  'addtreeviewentry'         => 'Hinzuf&#252;gen',
                  'admin'                    => 'Administrator',
                  'failed: invalid code'     => 'Fehler: falscher Captcha Code',
                  'newindex'                 => 'Neuer Index',
                  'newdir'                   => 'Explorer',
                  'createuser'               => 'Benutzer erstellen',
                  'editentry'                => 'Eintrag bearbeiten',
                  'saverights'               => 'Datenbank',
                  'getpass'                  => 'Passwort vergessen',
                  'null'                     => 'Null',
                  'retry'                    => 'Wiederholen',
                  'exportoperabookmarks'     => 'Opera Lesezeichen exportieren',
                  'multipledbaction'         => 'Datenbank',
                  'preview'                  => 'Vorschau',
                  'bookmarks'                => 'Lesezeichen',
                  'type'                     => 'type',
                  'repairtable'              => 'Reparieren',
                  'fileopen'                 => 'fileopen',
                  'newpass'                  => 'Neues Passwort',
                  'rows in effect'           => 'rows in effect',
                  'dropdatabase'             => 'Datenbank löschen',
                  'after'                    => 'nach',
                  'city'                     => 'Stadt',
                  'column_name'              => 'Spalten Name',
                  'analyzetable'             => 'Analysieren',
                  'showtables'               => 'Anzeigen',
                  'limit'                    => 'Limit',
                  'newmessagereleased'       => 'Nachricht wurde gespeichert',
                  'familyname'               => 'Nachname',
                  'auswahl aufheben'         => 'Auswahl aufheben',
                  'back'                     => 'zur&#252;ck',
                  'datenbank'                => 'Datenbank',
                  't_regtext'                => 'Registrieren',
                  'readmore'                 => 'ganzen Atikel lesen',
                  'phone'                    => 'Telefonnummer',
                  'createindex'              => 'Index erstellen',
                  'host'                     => 'Host',
                  'showtabledetails'         => 'Details',
                  'edittranslation'          => 'Übersetzen',
                  'navigation'               => 'Navigation',
                  'register'                 => 'Registrieren',
                  'mailsubject'              => 'Registrierung',
                  'permissiondenied'         => 'Keine Berechtigung',
                  'indexover'                => 'Index &#252;ber',
                  'execsql'                  => 'Sql ausf&#252;hren',
                  'news'                     => 'Logbook',
                  'optimize'                 => 'Optimieren',
                  'importfirefoxbookmarks'   => 'importfirefoxbookmarks',
                  'headline'                 => '&#220;berschrift',
                  'rights'                   => 'Rechte',
                  'edit entry'               => 'Eintrag Bearbeiten',
                  'renamefile'               => 'Umbenennen',
                  'table'                    => 'Tabelle',
                  'searchdatabase'           => 'Suchen',
                  'caption'                  => '&#220;berschrift',
                  'drop_database'            => 'drop_database',
                  'dragsharelink'            => 'Ins lesezeichen Menu ziehen',
                  'regmessage'               => 'Du ehälst diese Email weil versucht wurde sich damit bei uns zu registrieren \\nWenn Du diese Mail nicht angefordert hast bitte ich um entschuldigung.\\nAnsonsten lautet Dein \\n',
                  'processlist'              => 'Processlist',
                  'kontakt'                  => 'Kontakt',
                  'folderfirst'              => 'Verzeichnisse zuerst',
                  'lang'                     => 'de',
                  'newfile'                  => 'Explorer',
                  'sql'                      => 'SQL',
                  'createtable'              => 'Tabelle erstellen',
                  'saveentry'                => 'Eintrag speichern',
                  'edittree'                 => 'Bearbeiten',
                  'username'                 => 'Benutzer',
                  'catslist'                 => 'Kategorien',
                  'deletetreeviewentry'      => 'Löschen',
                  'showusers'                => 'Benutzer&#160;Anzeigen',
                  'showvariables'            => 'Variablen',
                  'changeautoincrementvalue' => 'autoincrement wert &#228;ndern',
                  'explorer'                 => 'Explorer',
                  'showtable'                => 'Tabelle Anzeigen',
                  'news_pro_page'            => 'Nachrichten/Seite',
                  'optimizetable'            => 'Optimieren',
                  'welcome'                  => 'Willkommen',
                  'packed'                   => 'Gepackt',
                  'edit'                     => 'Bearbeiten',
                  'newpost'                  => 'Neue Nachricht',
                  'permalink'                => 'Permalink',
                  'size'                     => 'Gr&ouml;&szlig;e',
                  'body'                     => 'Text',
                  'summary'                  => 'Zusammenfassung',
                  'checkformsddfsds'         => 'true',
                  'edittreeviewentry'        => 'Bearbeiten',
                  'editfile'                 => 'Datei bearbeiten',
                  'newfileadded'             => 'Neue Datei wurde erstellt',
                  'referer'                  => 'Referer',
                  'choosefile'               => 'File ausw&#228;hlen',
                  'create'                   => 'Erstellen',
                  'editlinks'                => 'Lesezeichen',
                  'shownewentry'             => 'Neuer Eintrag',
                  'deleteentry'              => 'Eintrag löschen',
                  'env'                      => 'Variablen',
                  'key_name'                 => 'Schl&#252;ssel',
                  'repair'                   => 'Reparieren',
                  'database'                 => 'Datenbank',
                  'reg'                      => 'Registrieren',
                  'regexp'                   => 'Regulärer Ausdruck',
                  'inserttext'               => 'Text einf&#252;gen',
                  'firstname'                => 'Vorname',
                  'done'                     => 'Gespeichert',
                  'search'                   => 'Suchen',
                  'street'                   => 'Strasse',
                  'insertpass'               => 'Passwort eingeben',
                  'edit table'               => 'Bearbeiten',
                  'about'                    => '&#220;ber',
                  'floodtext'                => 'Nicht so oft posten',
                  'answers'                  => 'Antworten',
                  'field'                    => 'field',
                  'show'                     => 'Anzeigen',
                  'sites'                    => 'Seiten',
                  'truncatetable'            => 'Datenbank',
                  'newcol'                   => 'Neue Zeile',
                  'nomail'                   => 'Du hast keine email adresse angegeben.',
                  'rebuild'                  => 'Wiederherstellen',
                  'editconfiguration'        => 'editconfiguration',
                  'insertname'               => 'Namen eingeben',
                  'fileexists'               => 'Datei existiert bereits',
                  'newtreeviewentry'         => 'Neuer Eintrag',
                  'downentry'                => 'Bearbeiten',
                  'pocesslist'               => 'pocesslist',
                  'buildfeeds'               => 'Rss',
                  'edittreeview'             => 'Bearbeiten',
                  'newtable'                 => 'Neue Tabelle',
                  'userexits'                => 'Dieser Benutzer exestiert bereits bitte einen anderen Namen ausw&#228;hlen<br/>',
                  'wrongpass'                => 'Falsches Passwort',
                  'alle markieren'           => 'Alle markieren',
                  'daten'                    => 'Daten',
                  'starttable'               => 'am Anfang',
                  'gbook_body'               => 'Text einf&#252;gen',
                  'impressum'                => 'Impressum',
                  'sharelink'                => 'Teilen',
                  'sub_part'                 => 'sub_part',
                  'mysqldump'                => 'Exportieren',
                  'realy'                    => 'Wirklich',
                  'help'                     => 'Hilfe',
                  'editmessage'              => 'Bearbeiten',
                  'postcode'                 => 'Postleitzahl',
                  'connect'                  => 'Verbinden',
                  'gbook'                    => 'G&#228;stebuch',
                  'dumptable'                => 'Tabelle exportieren',
                  'databases'                => 'Datenbanken',
                  'blog'                     => 'Logbook',
                  'settings'                 => 'Settings',
                  'reply'                    => 'Antworten',
                  'seq_in_index'             => 'seq_in_index',
                  'comment'                  => 'Kommentar',
                  'shownewtable'             => 'Neue Tabelle',
                  'savetranslate'            => 'Gespeichert',
                  'selected'                 => 'Alle ausw&#228;hlen',
                  'changeengine'             => 'Engine &#228;ndern',
                  'newmessage'               => 'Neue Nachricht',
                  'showwindow'               => 'Fenster anzeigen'
         },
         'es' => {
                  'insert'                   => 'Insertar',
                  'openfile'                 => 'Explorer',
                  'files'                    => 'Explorer',
                  'editmysqluserrights'      => 'Editar los permisos de los usuarios',
                  'boxen'                    => 'boxen',
                  'save'                     => 'Guardar',
                  'rename'                   => 'Renombrar',
                  'email'                    => 'Email',
                  'password'                 => 'Clave',
                  'optionaleemailadresse'    => 'Direcci&#243;n de correo opcional',
                  'wrongusername'            => 'Usuario incorrecto',
                  'edittable'                => 'Editar tabla',
                  'admincenter'              => 'Admininistraci&#243;n',
                  'logout'                   => 'Desconectar',
                  'endtable'                 => 'al final',
                  'category'                 => 'Categor&#237;a',
                  'newmenu'                  => 'Crear nuevo Men&#250;',
                  'multipleaction'           => 'Varias acciones',
                  'name'                     => 'Nombre',
                  'movetreeviewentry'        => 'TreeView',
                  'details'                  => 'Detalles',
                  'properties'               => 'Propiedades',
                  'importfirefox'            => 'Importar marcadores de FireFox',
                  'dumpdatabase'             => 'Borrar Base de datos',
                  'trash'                    => 'Basura',
                  'unselect_all'             => 'No seleccionar nada',
                  'translate'                => 'Trasladar',
                  'showrights'               => 'Mostrar derechos',
                  'editvmenu'                => 'Editar Men&#250; vertical',
                  'delete'                   => 'Borrar',
                  'chars'                    => 'Caracteres a la izquierda:',
                  'links_pro_page'           => 'enlaces/p&#225;gina',
                  'non_unique'               => 'No_unicos',
                  'saveedittable'            => 'Guardar tabla',
                  'mailsendet'               => '<div align="center">Se le ha enviado un correo con su contrase&#241;a.<br/></div>',
                  'showfiles'                => 'Mostrar archivos',
                  'deletefile'               => 'Borrar archivo',
                  'insertafter'              => 'Despu&#233;s',
                  'changecurrentdb'          => 'Cambiar el usuario de la Base de datos',
                  'cardinality'              => 'Cardinalidad',
                  'createnewtable'           => 'Crear nueva tabla',
                  'speichern'                => 'Speichern',
                  'showdatabases'            => 'Bases de datos',
                  'pass'                     => 'Clave',
                  'truncate'                 => 'Truncar',
                  'showeditindex'            => 'Mostrar &#237;ndice',
                  'edithmenu'                => 'Editar Men&#250; horizontal',
                  'editnavi'                 => 'Editar navegaci&#243;n',
                  'sort'                     => 'Ordenar',
                  'edittableprops'           => 'Database',
                  'fields'                   => 'Campos',
                  'select_all'               => 'Seleccionar Todo',
                  'index_type'               => 'Tipo &#237;ndice',
                  'profile'                  => 'Perfil',
                  'next'                     => 'Siguiente',
                  'importoperabookmarks'     => 'Importar marcadores de Opera',
                  'feeds'                    => 'Rss',
                  'upentry'                  => 'Ordenar',
                  'exportdatabase'           => 'Exportar',
                  'comments'                 => 'Comentarios',
                  'newentry'                 => 'Nueva entrada',
                  'editaction'               => 'Acci&#243;n Editar',
                  'createdatabase'           => 'Nueva base de datos',
                  'nachricht'                => 'mensaje',
                  'chmodfile'                => 'Explorer',
                  'makedir'                  => 'Explorer',
                  'lostpass'                 => 'Clave perdida',
                  'savefile'                 => 'Explorer',
                  'newfolder'                => 'A&#241;dir',
                  'export'                   => 'Export',
                  'haveacount'               => 'Ya tiene una cuenta',
                  'savetreeviewentry'        => 'TreeView',
                  'links'                    => 'Mapa del sitio',
                  'newindex'                 => 'Nuevo &#205;ndice',
                  'failed: invalid code'     => 'fallo: c&oacute:digo no v&aacute;lido',
                  'admin'                    => 'Administraci&#243;n',
                  'addtreeviewentry'         => 'A&#241;adir nueva entrada',
                  'newdir'                   => 'Explorer',
                  'createuser'               => 'Crear Usuario',
                  'saverights'               => 'Base de datos',
                  'editentry'                => 'Editar entrada',
                  'getpass'                  => 'Clave Perdida',
                  'null'                     => 'Null',
                  'retry'                    => 'reintentar',
                  'exportoperabookmarks'     => 'Marcadores',
                  'multipledbaction'         => 'Base de datos',
                  'preview'                  => 'Vista previa',
                  'bookmarks'                => 'Marcadores',
                  'type'                     => 'tipo',
                  'repairtable'              => 'Reparar tabla',
                  'newpass'                  => 'Nueva clave',
                  'rows in effect'           => 'filas afectadas',
                  'dropdatabase'             => 'Borrar base de datos',
                  'after'                    => 'despu&#233;s',
                  'city'                     => 'Ciudad',
                  'column_name'              => 'Nombre Columna',
                  'showtables'               => 'Mostrar tablas',
                  'analyzetable'             => 'Analizar tablas',
                  'familyname'               => 'Apellidos',
                  'auswahl aufheben'         => 'Borrar selecci&#243;n',
                  't_regtext'                => 'Registrar',
                  'datenbank'                => 'Base de datos',
                  'back'                     => 'Volver',
                  'readmore'                 => 'Leer m&#225;s',
                  'phone'                    => 'N&uacute;mero de tel&eacute;fono',
                  'showtabledetails'         => 'Mostrar detalles de tabla',
                  'createindex'              => 'Base de datos',
                  'register'                 => 'Registrar',
                  'navigation'               => 'Navegaci&#243;n',
                  'mailsubject'              => 'Asunto',
                  'permissiondenied'         => 'permiso denegado',
                  'indexover'                => 'Indexover',
                  'optimize'                 => 'Optimizar',
                  'news'                     => 'Registros',
                  'execsql'                  => 'Ejecutar Sql',
                  'headline'                 => 'Cabecera',
                  'rights'                   => 'Permisos',
                  'edit entry'               => 'Editar entrada',
                  'table'                    => 'Tabla',
                  'caption'                  => 'T&#237;tulo',
                  'regmessage'               => 'Ha recibido este correo desde Lindnerei.de',
                  'dragsharelink'            => 'Arrastre el enlace a sus marcadores',
                  'lang'                     => 'es',
                  'sql'                      => 'SQL',
                  'newfile'                  => 'Explorer',
                  'folderfirst'              => 'Carpetas primero',
                  'createtable'              => 'Crear tabla',
                  'saveentry'                => 'Guardar entrada',
                  'edittree'                 => 'Editar',
                  'username'                 => 'Usuario',
                  'showusers'                => 'Mostrar usuarios',
                  'deletetreeviewentry'      => 'Borrar',
                  'showtable'                => 'Mostrar tablas',
                  'explorer'                 => 'Explorer',
                  'changeautoincrementvalue' => 'Base de datos',
                  'news_pro_page'            => 'Noticias',
                  'optimizetable'            => 'Optimizar tabla',
                  'welcome'                  => 'Bienvenido',
                  'packed'                   => 'Comprimido',
                  'newpost'                  => 'Nuevo mensaje',
                  'edit'                     => 'Editar',
                  'size'                     => 'Tama&#241;o',
                  'body'                     => 'Cuerpo',
                  'summary'                  => 'Sumario',
                  'checkformsddfsds'         => 'true',
                  'edittreeviewentry'        => 'Editor',
                  'editfile'                 => 'Editor',
                  'newfileadded'             => 'Nuevo archivo creado',
                  'referer'                  => 'Referer',
                  'create'                   => 'Crear',
                  'choosefile'               => 'Elegir anexo',
                  'editlinks'                => 'Editar enlaces',
                  'shownewentry'             => 'Nueva entrada',
                  'deleteentry'              => 'Borrar entrada',
                  'env'                      => 'Env',
                  'repair'                   => 'Reparar',
                  'key_name'                 => 'Nombre clave',
                  'database'                 => 'Base de datos',
                  'reg'                      => 'Registrar',
                  'inserttext'               => 'Insertar texto',
                  'firstname'                => 'Nombre',
                  'search'                   => 'Buscar',
                  'done'                     => 'Hecho',
                  'street'                   => 'Calle',
                  'insertpass'               => 'Insertar clave',
                  'edit table'               => 'Editar tabla',
                  'about'                    => 'Acerca de',
                  'floodtext'                => 'Demasiadas entradas',
                  'field'                    => 'campo',
                  'answers'                  => 'Respuestas',
                  'sites'                    => 'Sitios',
                  'show'                     => 'Mostrar',
                  'truncatetable'            => 'Truncar',
                  'nomail'                   => 'No se ha especificado ninguna direcci&#243;n de email.',
                  'newcol'                   => 'Nueva columna',
                  'insertname'               => 'Inserte su nombre',
                  'editconfiguration'        => 'editconfiguration',
                  'fileexists'               => 'El archivo ya existe',
                  'newtreeviewentry'         => 'Nueva entrada',
                  'downentry'                => 'Ordenar',
                  'buildfeeds'               => 'Rss',
                  'userexits'                => 'Ese nombre ya est&#225; en uso.<br/>',
                  'newtable'                 => 'Nueva tabla',
                  'edittreeview'             => 'Editar',
                  'wrongpass'                => 'Contrase&#241;a incorrecta',
                  'starttable'               => 'al principio',
                  'sub_part'                 => 'sub_part',
                  'sharelink'                => 'Compartir',
                  'impressum'                => 'Impreso',
                  'gbook_body'               => 'Insertar texto',
                  'mysqldump'                => 'Mysql dump',
                  'realy'                    => 'Realmente',
                  'help'                     => 'Ayuda',
                  'postcode'                 => 'C&#243;digo postal',
                  'editmessage'              => 'Editar',
                  'gbook'                    => 'Gbook',
                  'connect'                  => 'Conectar',
                  'dumptable'                => 'Bases de datos',
                  'databases'                => 'Bases de datos',
                  'blog'                     => 'Logbook',
                  'settings'                 => 'Configuraci&#243;n',
                  'seq_in_index'             => 'Seq_in_index',
                  'reply'                    => 'Responder',
                  'comment'                  => 'Comentario',
                  'action'                   => 'action',
                  'selected'                 => 'Seleccionar todo',
                  'showwindow'               => 'Mostrar ventanas',
                  'newmessage'               => 'Nuevo tema',
                  'changeengine'             => 'Cambiar motor'
         }
};
$lang = $VAR1;
