$VAR1 = [
         {
          'text'    => 'Sourceforge Sites',
          'subtree' => [
                        {
                         'rel'         => '',
                         'ondblclick'  => '',
                         'onkeydown'   => '',
                         'target'      => '_blank',
                         'onkeyup'     => '',
                         'href'        => 'http://sourceforge.net/projects/lindnerei/',
                         'onmouseup'   => '',
                         'subtree'     => [],
                         'id'          => 'a2',
                         'onmouseover' => '',
                         'lang'        => '',
                         'name'        => '',
                         'rid'         => 2,
                         'charset'     => '',
                         'hreflang'    => '',
                         'onkeypress'  => '',
                         'onmousedown' => '',
                         'rev'         => '',
                         'onclick'     => '',
                         'shape'       => '',
                         'title'       => '',
                         'type'        => '',
                         'accesskey'   => '',
                         'coords'      => '',
                         'dir'         => '',
                         'onblur'      => '',
                         'onfocus'     => '',
                         'text'        => 'Project Site',
                         'tabindex'    => '',
                         'onmousemove' => '',
                         'onmouseout'  => '',
                         'style'       => '',
                         'right'       => ''
                        },
                        {
                         'target'  => '_blank',
                         'href'    => 'http://sourceforge.net/project/showfiles.php?group_id=155379/',
                         'text'    => 'Downloads',
                         'subtree' => [],
                         'rid'     => 3,
                         'id'      => 'a3'
                        },
                        {
                         'target'  => '_blank',
                         'href'    => 'http://lindnerei.svn.sourceforge.net/viewvc/lindnerei/',
                         'text'    => 'Svn',
                         'subtree' => [],
                         'rid'     => 4,
                         'id'      => 'a4'
                        },
                        {
                         'target'  => '_blank',
                         'href'    => 'https://sourceforge.net/project/screenshots.php?group_id=155379',
                         'text'    => 'Screenshots',
                         'subtree' => [],
                         'rid'     => 5,
                         'id'      => 'a5'
                        }
          ],
          'rid' => 1,
          'id'  => 'a1'
         },
         {
          'target'  => '_blank',
          'href'    => 'http://search.cpan.org/dist/MySQL-Admin/',
          'text'    => 'Cpan',
          'subtree' => [],
          'rid'     => 6,
          'id'      => 'a6'
         },
         {
          'target'  => '_blank',
          'href'    => 'mailto:lze@cpan.org',
          'text'    => 'Contact',
          'subtree' => [],
          'rid'     => 7,
          'id'      => 'a7'
         },
         {
          'text'    => 'Related Sites',
          'subtree' => [
                        {
                         'target'  => '_blank',
                         'href'    => 'http://lindnerei.de/',
                         'text'    => 'Lindnerei.de',
                         'subtree' => [],
                         'rid'     => 9,
                         'id'      => 'a9'
                        },
                        {
                         'target'  => '_blank',
                         'href'    => 'http://treeview.lindnerei.de',
                         'text'    => 'treeview.lindnerei',
                         'subtree' => [],
                         'rid'     => 10,
                         'id'      => 'a10'
                        }
          ],
          'rid' => 8,
          'id'  => 'a8'
         },
         {
          'text'    => 'Examples',
          'subtree' => [
                        {
                         'target'  => '_blank',
                         'text'    => 'MySQL::Admin::Main',
                         'href'    => 'http://lindnerei.sourceforge.net/cgi-bin/examples/main.pl',
                         'subtree' => [],
                         'id'      => 'a12',
                         'rid'     => 12
                        },
                        {
                         'target'  => '_blank',
                         'text'    => 'MySQL::Admin include OO',
                         'href'    => 'http://lindnerei.sourceforge.net/cgi-bin/examples/include-oo.pl',
                         'subtree' => [],
                         'id'      => 'a13',
                         'rid'     => 13
                        },
                        {
                         'target'  => '_blank',
                         'text'    => 'MySQL::Admin include FO',
                         'href'    => 'http://lindnerei.sourceforge.net/cgi-bin/examples/include-fo.pl',
                         'subtree' => [],
                         'id'      => 'a14',
                         'rid'     => 14
                        },
                        {
                         'target'  => '_blank',
                         'text'    => 'DBI::Library OO',
                         'href'    => 'http://lindnerei.sourceforge.net/cgi-bin/examples/DBI-OO.pl',
                         'subtree' => [],
                         'id'      => 'a15',
                         'rid'     => 15
                        },
                        {
                         'target'  => '_blank',
                         'text'    => 'DBI::Library FO',
                         'href'    => 'http://lindnerei.sourceforge.net/cgi-bin/examples/DBI-FO.pl',
                         'subtree' => [],
                         'id'      => 'a16',
                         'rid'     => 16
                        },
                        {
                         'target'  => '_blank',
                         'href'    => 'http://lindnerei.sourceforge.net/cgi-bin/examples/window.pl',
                         'text'    => 'HTML::Window',
                         'subtree' => [],
                         'rid'     => 17,
                         'id'      => 'a17'
                        },
                        {
                         'target'  => '_blank',
                         'href'    => 'http://lindnerei.sourceforge.net/cgi-bin/examples/pages.pl',
                         'text'    => 'HTML::Menu::Pages',
                         'subtree' => [],
                         'rid'     => 18,
                         'id'      => 'a18'
                        },
                        {
                         'target'  => '_blank',
                         'href'    => 'http://lindnerei.sourceforge.net/cgi-bin/examples/tabwidget.pl',
                         'text'    => 'HTML::TabWidget',
                         'subtree' => [],
                         'rid'     => 19,
                         'id'      => 'a19'
                        },
                        {
                         'target'  => '_blank',
                         'href'    => 'http://lindnerei.sourceforge.net/cgi-bin/examples/editor.pl',
                         'text'    => 'HTML::Editor',
                         'subtree' => [],
                         'rid'     => 20,
                         'id'      => 'a20'
                        },
                        {
                         'target'  => '_blank',
                         'href'    => 'http://lindnerei.sourceforge.net/cgi-bin/examples/template.pl',
                         'text'    => 'Template::Quick',
                         'subtree' => [],
                         'rid'     => 21,
                         'id'      => 'a21'
                        }
          ],
          'rid' => 11,
          'id'  => 'a11'
         },
         {
          'rel'         => '',
          'ondblclick'  => '',
          'onkeydown'   => '',
          'target'      => '_blank',
          'onkeyup'     => '',
          'href'        => 'http://sourceforge.net/perldoc.shtml',
          'onmouseup'   => '',
          'subtree'     => [],
          'id'          => 'a22',
          'onmouseover' => '',
          'lang'        => '',
          'name'        => '',
          'rid'         => 22,
          'charset'     => '',
          'hreflang'    => '',
          'onmousedown' => '',
          'onkeypress'  => '',
          'rev'         => '',
          'type'        => '',
          'title'       => '',
          'shape'       => '',
          'onclick'     => '',
          'accesskey'   => '',
          'coords'      => '',
          'dir'         => '',
          'onblur'      => '',
          'onfocus'     => '',
          'text'        => 'Dokumentation',
          'tabindex'    => '',
          'onmousemove' => '',
          'onmouseout'  => '',
          'style'       => '',
          'right'       => ''
         }
];
@TreeView = $VAR1;
