$VAR1 = [
         {
          'text'    => 'Kontakt',
          'href'    => 'mailto:lze@cpan',
          'subtree' => [],
          'rid'     => 1
         },
         {
          'text'    => 'Projects',
          'subtree' => [
                        {
                         'text'    => 'Empty Folder',
                         'subtree' => [],
                         'rid'     => 3
                        }
          ],
          'rid' => 2
         }
];
@TreeView = $VAR1;
